@@ -2,66 +2,33 @@ use v6.c;
 
 unit module Bailador::CLI;
 
-sub skeleton() is export {
+sub write-skeletonfiles(Str $appname, Str $type = 'default') is export {
+
     my %skeleton;
-%skeleton{'bin/app.pl6'} =
-q{use v6.c;
-use Bailador;
+    # thats not cool :(
+    if $type eq 'default' {
+        %skeleton<bin><app.pl6>      = %?RESOURCES<skeleton/default/bin/app.pl6>.IO.slurp;
+        %skeleton<t><app.t>          = %?RESOURCES<skeleton/default/t/app.t>.IO.slurp;
+        %skeleton<views><index.html> = %?RESOURCES<skeleton/default/views/index.html>.IO.slurp;
+    } else {
+        X::NYI.new(feature => 'skeleton with type ' ~ $type).throw;
+    }
 
-my $version = '0.0.1';
+    mkdir $appname;
+    sub create-files(IO::Path $dir, %data) {
+        for %data.kv -> $filename, $data {
+            if $data ~~ Hash {
+                my $subdir = $dir.add($filename).mkdir;
+                create-files($subdir, $data);
+            } else {
+                my $file = $dir.add($filename);
+                $file.spurt($data);
+                say $file.Str;
+            }
+        }
 
-get '/' => sub {
-    template 'index.html', { version => $version }
-}
-
-baile();
-};
-
-%skeleton{'t/app.t'} =
-q{use v6.c;
-use Test;
-use Bailador::Test;
-
-plan 1;
-
-%*ENV<P6W_CONTAINER> = 'Bailador::Test';
-%*ENV<BAILADOR_APP_ROOT> = $*CWD.absolute;
-my $app = EVALFILE "bin/app.pl6";
-
-subtest {
-    plan 4;
-    my %data = run-psgi-request($app, 'GET', '/');
-    my $html = %data<response>[2];
-    %data<response>[2] = '';
-    is-deeply %data<response>, [200, ["Content-Type" => "text/html"], ''], 'route GET /';
-    is %data<err>, '';
-    like $html, rx:s/\<h1\>Bailador App\<\/h1\>/;
-    like $html, rx:s/Version 0\.0\.1/;
-}, '/';
-};
-
-%skeleton{'views/index.html'} =
-q{
-% my ($h) = @_;
-<!DOCTYPE html>
-<html>
-  <head>
-    <title>Bailador App</title>
-    <meta charset="utf-8">
-    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=yes">
-    <script src="https://cdnjs.cloudflare.com/ajax/libs/handlebars.js/3.0.3/handlebars.min.js"></script>
-    <script src="http://code.jquery.com/jquery-1.11.3.min.js"></script>
-  </head>
-  <body>
-    <h1>Bailador App</h1>
-    <div>
-      Version <%= $h<version> %>
-    </div>
-  </body>
-</html>
-};
-
-    return %skeleton;
+    }
+    create-files($appname.IO, %skeleton);
 }
 
 my multi sub bootup-file ('watch', Str $app, Str $w, Str $config?) is export {
@@ -110,12 +77,21 @@ multi sub bootup-file (Str $app) {
     await $p.start;
 }
 
-sub repo-to-includes is export {
+sub get-path-from-repo is export {
     my @includes;
     for $*REPO.repo-chain -> $repo {
         if $repo ~~ CompUnit::Repository::FileSystem {
-            @includes.push: '-I' ~ $repo.prefix;
+            @includes.push: $repo.prefix;
         }
     }
     return @includes;
 }
+
+sub repo-to-includes is export {
+    get-path-from-repo().map: '-I' ~ *;
+}
+
+sub run-executable-with-includes(*@args, *%args) is export {
+    my @includes = repo-to-includes();
+    return run($*EXECUTABLE, |@includes, |@args, |%args);
+}
